@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from . import Price
+from .PriceModel import Price
 
 class ShippingProfileUpgrade(BaseModel):
     shipping_profile_id: int
